import { VariableRegistry } from '@opensumi/ide-core-browser';
import { IVariableResolverService, VariableResolveOptions } from '../common';
export declare class VariableResolverService implements IVariableResolverService {
    protected static VAR_REGEXP: RegExp;
    protected readonly variableRegistry: VariableRegistry;
    /**
     * 处理给定的变量数组
     * @param value 需要处理的变量数组
     * @param options 处理参数
     */
    resolveArray(value: string[], options?: VariableResolveOptions): Promise<string[]>;
    /**
     * 变量处理函数
     * @param value 变量
     * @param options 处理参数
     */
    resolve<T>(value: T, options?: VariableResolveOptions): Promise<T>;
    /**
     * 实际处理函数
     * @param value
     * @param context
     */
    protected doResolve(value: any, context: VariableResolverService.Context): Promise<any>;
    /**
     * 获取对象值
     * @param obj
     * @param context
     */
    protected doResolveObject(obj: object, context: VariableResolverService.Context): Promise<object>;
    /**
     * 获取数组值
     * @param values
     * @param context
     */
    protected doResolveArray(values: Array<any>, context: VariableResolverService.Context): Promise<Array<any>>;
    /**
     * 获取字符串值
     * @param value
     * @param context
     */
    protected doResolveString(value: string, context: VariableResolverService.Context): Promise<string>;
    protected resolveVariables(value: string, context: VariableResolverService.Context): Promise<void>;
}
export declare namespace VariableResolverService {
    class Context {
        protected readonly variableRegistry: VariableRegistry;
        protected readonly options: VariableResolveOptions;
        protected readonly resolved: Map<string, string | undefined>;
        constructor(variableRegistry: VariableRegistry, options: VariableResolveOptions);
        private evaluateSingleVariable;
        get(name: string): string | undefined;
        resolve(name: string): Promise<void>;
    }
}
//# sourceMappingURL=variable-resolver.service.d.ts.map